aboutsummaryrefslogtreecommitdiff
path: root/keyboards/mode/m65hi_alpha/m65hi_alpha.c
diff options
context:
space:
mode:
Diffstat (limited to 'keyboards/mode/m65hi_alpha/m65hi_alpha.c')
-rw-r--r--keyboards/mode/m65hi_alpha/m65hi_alpha.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/keyboards/mode/m65hi_alpha/m65hi_alpha.c b/keyboards/mode/m65hi_alpha/m65hi_alpha.c
index afb093058f..0d438b02de 100644
--- a/keyboards/mode/m65hi_alpha/m65hi_alpha.c
+++ b/keyboards/mode/m65hi_alpha/m65hi_alpha.c
@@ -18,7 +18,7 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
#include "quantum.h"
void board_init(void) {
- setPinInput(B10);
+ gpio_set_pin_input(B10);
}
void led_init_ports(void) {
@@ -54,12 +54,12 @@ void led_init_ports(void) {
bool led_update_kb(led_t led_state) {
bool res = led_update_user(led_state);
if(res) {
// writePin sets the pin high for 1 and low for 0.
// In this example the pins are inverted, setting
// it low/0 turns it on, and high/1 turns the LED off.
// This behavior depends on whether the LED is between the pin
// and VCC or the pin and GND.
- writePin(LED_CAPS_LOCK_PIN, !led_state.caps_lock);
+ gpio_write_pin(LED_CAPS_LOCK_PIN, !led_state.caps_lock);
}
return res;
}
@@ -54,12 +54,12 @@ void led_init_ports(void) {
bool res = led_update_user(led_state);
if(res) {
- // writePin sets the pin high for 1 and low for 0.
+ // gpio_write_pin sets the pin high for 1 and low for 0.
// In this example the pins are inverted, setting
// it low/0 turns it on, and high/1 turns the LED off.